@@ -9,7 +9,7 @@ logging.basicConfig(
 
 
 class DBConnect():
-    def __init__(self, db, collection, home_kye='MONGODB_HOST', port_kye='MONGODB_PORT'):
+    def __init__(self, db: str, collection: str, home_kye='MONGODB_HOST', port_kye='MONGODB_PORT'):
         self.mongo_home = os.environ.get(home_kye, None)
         self.mongo_port = os.environ.get(port_kye, 27017)
 
@@ -23,10 +23,7 @@ class DBConnect():
         self.mongo_db = self.mongo_client[db]
         self.mongo_collection = self.mongo_db[collection]
 
-    def get_collection(self):
-        return self.mongo_collection
-
-    def write_one_docu(self, docu):
+    def write_one_docu(self, docu: dict) -> bool:
         try:
             self.mongo_collection.insert_one(docu)
             return True
